@@ -1,35 +1,49 @@
 # -*- coding:utf-8 -*-
 # !/usr/bin/env python
 """
-Date: 2022/2/23 20:05
+Date: 2022/9/16 20:05
 Desc: 主程序入口
 """
 import akshare
 import uvicorn
-from fastapi import FastAPI
+from fastapi import FastAPI, Request
 from fastapi.middleware.cors import CORSMiddleware
+from fastapi.responses import FileResponse
 
 from core import app_core
+from datasets import get_favicon_path, get_homepage_html
 from login import app_user_login
+from core.api import templates
 
-from starlette.responses import FileResponse
-
-from datasets import get_favicon_path
 
 favicon_path = get_favicon_path(file="favicon.ico")
+html_path = get_homepage_html(file="homepage.html")
+
 
 app = FastAPI(
     title="欢迎来到为 AKShare 打造的 HTTP API 文档",
-    description="AKTools 是 AKShare 的 HTTP API 工具, 主要目的是使 AKShare 的数据接口部署到本地从而通过 HTTP 访问来获取所需要的数据",
+    description="AKTools 是 AKShare 的 HTTP API 工具, 主要目的是使 AKShare 的数据接口部署到服务器从而通过 HTTP 访问来获取所需要的数据",
     version=akshare.__version__,
 )
 
 
-@app.get('/favicon.ico')
-async def favicon():
+@app.get("/favicon.ico")
+async def favicon() -> FileResponse:
     return FileResponse(favicon_path)
 
-origins = ["*"]
+
+@app.get("/")
+async def get_homepage(request: Request):
+    return templates.TemplateResponse(
+        "homepage.html",
+        context={
+            "request": request,
+            "ip_address": request.headers["host"],
+        },
+    )
+
+
+origins = ["*"]  # 此处设置可以访问的协议，IP和端口信息
 
 app.add_middleware(
     CORSMiddleware,
